import request from '@/utils/request'

// 查询订餐消费维护列表
export function listMaintain(query) {
  return request({
    url: '/consume/maintain/list',
    method: 'get',
    params: query
  })
}

// 查询订餐消费维护详细
export function getMaintain(id) {
  return request({
    url: '/consume/maintain/' + id,
    method: 'get'
  })
}

// 新增订餐消费维护
export function addMaintain(data) {
  return request({
    url: '/consume/maintain',
    method: 'post',
    data: data
  })
}

// 修改订餐消费维护
export function updateMaintain(data) {
  return request({
    url: '/consume/maintain',
    method: 'put',
    data: data
  })
}

// 删除订餐消费维护
export function delMaintain(id) {
  return request({
    url: '/consume/maintain/' + id,
    method: 'delete'
  })
}

// 导出订餐消费维护
export function exportMaintain(query) {
  return request({
    url: '/consume/maintain/export',
    method: 'get',
    params: query
  })
}

export function queryMenuDict(query) {
  return request({
    url: '/canteen/menu/limitMenu',
    method: 'get',
    params: query
  })
}
